@@ -52,9 +52,9 @@ VALID_TRANSACTION_PARAMS: List[TX_PARAM_LITERALS] = [
 TRANSACTION_DEFAULTS = {
     'value': 0,
     'data': b'',
-    'gas': lambda web3, tx: web3.eth.estimateGas(tx),
-    'gasPrice': lambda web3, tx: web3.eth.generateGasPrice(tx) or web3.eth.gasPrice,
-    'chainId': lambda web3, tx: web3.eth.chainId,
+    'gas': lambda web3, tx: web3.eth.estimate_gas(tx),
+    'gasPrice': lambda web3, tx: web3.eth.generate_gas_price(tx) or web3.eth.gas_price,
+    'chainId': lambda web3, tx: web3.eth.chain_id,
 }
 
 if TYPE_CHECKING:
@@ -67,7 +67,7 @@ def fill_nonce(web3: "Web3", transaction: TxParams) -> TxParams:
         return assoc(
             transaction,
             'nonce',
-            web3.eth.getTransactionCount(
+            web3.eth.get_transaction_count(
                 cast(ChecksumAddress, transaction['from']),
                 block_identifier='pending'))
     else:
@@ -99,7 +99,7 @@ def wait_for_transaction_receipt(
     with Timeout(timeout) as _timeout:
         while True:
             try:
-                txn_receipt = web3.eth.getTransactionReceipt(txn_hash)
+                txn_receipt = web3.eth.get_transaction_receipt(txn_hash)
             except TransactionNotFound:
                 txn_receipt = None
             # FIXME: The check for a null `blockHash` is due to parity's
@@ -114,7 +114,7 @@ def wait_for_transaction_receipt(
 
 def get_block_gas_limit(web3: "Web3", block_identifier: Optional[BlockIdentifier] = None) -> Wei:
     if block_identifier is None:
-        block_identifier = web3.eth.blockNumber
+        block_identifier = web3.eth.block_number
     block = web3.eth.get_block(block_identifier)
     return block['gasLimit']
 
@@ -124,7 +124,7 @@ def get_buffered_gas_estimate(
 ) -> Wei:
     gas_estimate_transaction = cast(TxParams, dict(**transaction))
 
-    gas_estimate = web3.eth.estimateGas(gas_estimate_transaction)
+    gas_estimate = web3.eth.estimate_gas(gas_estimate_transaction)
 
     gas_limit = get_block_gas_limit(web3)
 
@@ -139,10 +139,9 @@ def get_buffered_gas_estimate(
 
 
 def get_required_transaction(web3: "Web3", transaction_hash: _Hash32) -> TxData:
-    current_transaction = web3.eth.getTransaction(transaction_hash)
+    current_transaction = web3.eth.get_transaction(transaction_hash)
     if not current_transaction:
-        raise ValueError('Supplied transaction with hash {} does not exist'
-                         .format(transaction_hash))
+        raise ValueError(f'Supplied transaction with hash {transaction_hash!r} does not exist')
     return current_transaction
 
 
@@ -186,8 +185,8 @@ def prepare_replacement_transaction(
     gas_multiplier: float = 1.125
 ) -> TxParams:
     if current_transaction['blockHash'] is not None:
-        raise ValueError('Supplied transaction with hash {} has already been mined'
-                         .format(current_transaction['hash']))
+        raise ValueError(f'Supplied transaction with hash {current_transaction["hash"]!r} '
+                         'has already been mined')
     if 'nonce' in new_transaction and new_transaction['nonce'] != current_transaction['nonce']:
         raise ValueError('Supplied nonce in new_transaction must match the pending transaction')
 
@@ -198,7 +197,7 @@ def prepare_replacement_transaction(
         if new_transaction['gasPrice'] <= current_transaction['gasPrice']:
             raise ValueError('Supplied gas price must exceed existing transaction gas price')
     else:
-        generated_gas_price = web3.eth.generateGasPrice(new_transaction)
+        generated_gas_price = web3.eth.generate_gas_price(new_transaction)
         minimum_gas_price = int(math.ceil(current_transaction['gasPrice'] * gas_multiplier))
         if generated_gas_price and generated_gas_price > minimum_gas_price:
             new_transaction = assoc(new_transaction, 'gasPrice', generated_gas_price)
@@ -214,4 +213,4 @@ def replace_transaction(
     new_transaction = prepare_replacement_transaction(
         web3, current_transaction, new_transaction
     )
-    return web3.eth.sendTransaction(new_transaction)
+    return web3.eth.send_transaction(new_transaction)
