@@ -37,10 +37,7 @@ from web3.types import (
 
 if TYPE_CHECKING:
     from web3 import Web3  # noqa: F401
-    from web3.module import (  # noqa: F401
-        Module,
-        ModuleV2,
-    )
+    from web3.module import Module  # noqa: F401
 
 Munger = Callable[..., Any]
 
@@ -62,14 +59,14 @@ def _munger_star_apply(fn: Callable[..., TReturn]) -> Callable[..., TReturn]:
     return inner
 
 
-def default_munger(module: Union["Module", "ModuleV2"], *args: Any, **kwargs: Any) -> Tuple[()]:
+def default_munger(module: "Module", *args: Any, **kwargs: Any) -> Tuple[()]:
     if not args and not kwargs:
         return ()
     else:
         raise TypeError("Parameters passed to method without parameter mungers defined.")
 
 
-def default_root_munger(module: Union["Module", "ModuleV2"], *args: Any) -> List[Any]:
+def default_root_munger(module: "Module", *args: Any) -> List[Any]:
     return [*args]
 
 
@@ -132,8 +129,8 @@ class Method(Generic[TFunc]):
         self.error_formatters = get_error_formatters
         self.method_choice_depends_on_args = method_choice_depends_on_args
 
-    def __get__(self, obj: Optional["ModuleV2"] = None,
-                obj_type: Optional[Type["ModuleV2"]] = None) -> TFunc:
+    def __get__(self, obj: Optional["Module"] = None,
+                obj_type: Optional[Type["Module"]] = None) -> TFunc:
         if obj is None:
             raise TypeError(
                 "Direct calls to methods are not supported. "
@@ -152,7 +149,7 @@ class Method(Generic[TFunc]):
         raise ValueError("``json_rpc_method`` config invalid.  May be a string or function")
 
     def input_munger(
-        self, module: Union["Module", "ModuleV2"], args: Any, kwargs: Any
+        self, module: "Module", args: Any, kwargs: Any
     ) -> List[Any]:
         # This function takes the "root_munger" - the first munger in
         # the list of mungers) and then pipes the return value of the
@@ -171,7 +168,7 @@ class Method(Generic[TFunc]):
         return munged_inputs
 
     def process_params(
-        self, module: Union["Module", "ModuleV2"], *args: Any, **kwargs: Any
+        self, module: "Module", *args: Any, **kwargs: Any
     ) -> Tuple[Tuple[Union[RPCEndpoint, Callable[..., Any]], Any], Tuple[Any, Any]]:
         params = self.input_munger(module, args, kwargs)
 
@@ -205,8 +202,8 @@ class DeprecatedMethod():
         self.old_name = old_name
         self.new_name = new_name
 
-    def __get__(self, obj: Optional["ModuleV2"] = None,
-                obj_type: Optional[Type["ModuleV2"]] = None) -> Any:
+    def __get__(self, obj: Optional["Module"] = None,
+                obj_type: Optional[Type["Module"]] = None) -> Any:
         warnings.warn(
             f"{self.old_name} is deprecated in favor of {self.new_name}",
             category=DeprecationWarning,
